# ex-cxx-basic

This example demonstrates the use of basic timemory instrumentation in C++. The auto tuple used for instrumentation contains the following components:
```c
auto_tuple_t = tim::auto_tuple_t<wall_clock, cpu_clock, cpu_util, peak_rss,
                                 papi_vector, caliper, tau_marker>;
```

## Build

See [examples](../README.md##Build).

## Expected Output

```bash
$ ./ex_cxx_basic
#------------------------- tim::manager initialized [id=0][pid=1574] -------------------------#

Initializing caliper...

fibonacci(15) = 610
>>>  fibonacci(15) :     0.015411 sec wall,     0.010000 sec cpu,   64.9 % cpu_util,        0.000 KB peak_rss, 30509710 Total cycles, 37679966 Instr completed, 20393348 L/S completed papi_vector0,  [laps: 2]

fibonacci(20) = 6765
>>>  fibonacci(20) :     0.144012 sec wall,     0.150000 sec cpu,  104.2 % cpu_util,        0.000 KB peak_rss, 328681214 Total cycles, 415768604 Instr completed, 225386036 L/S completed papi_vector0,  [laps: 2]

fibonacci(25) = 75025
>>>  fibonacci(25) :     1.331725 sec wall,     1.330000 sec cpu,   99.9 % cpu_util,        0.000 KB peak_rss, 3534498162 Total cycles, 4610100460 Instr completed, 2499648473 L/S completed papi_vector0,  [laps: 2]

>>>  ex_cxx_basic :     1.530347 sec wall,     0.240000 sec sys,     1.250000 sec user,   97.4 % cpu_util,     1876.000 KB peak_rss,  [laps: 1]
>>>  another_func :     0.010065 sec wall,     0.000000 sec cpu,    0.0 % cpu_util,  [laps: 1]
[peak_rss]|0> Outputting 'timemory-ex-cxx-basic-output/peak_rss.json'...
[peak_rss]|0> Outputting 'timemory-ex-cxx-basic-output/peak_rss.txt'...
Opening 'timemory-ex-cxx-basic-output/peak_rss.jpeg' for output...
Closed 'timemory-ex-cxx-basic-output/peak_rss.jpeg'...

|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
|                                          MEASURES CHANGES IN THE HIGH-WATER MARK FOR THE AMOUNT OF MEMORY ALLOCATED IN RAM. MAY FLUCTUATE IF SWAP IS ENABLED                                        |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
|                              LABEL                                |   COUNT    |   DEPTH    |   METRIC   |   UNITS    |    SUM     |    MEAN    |    MIN     |    MAX     |   STDDEV   |   % SELF   |
|-------------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>> ex_cxx_basic                                                  |          1 |          0 | peak_rss   | KB         |   1876.000 |   1876.000 |   1876.000 |   1876.000 |      0.000 |      100.0 |
| >>> |_fibonacci(15)                                               |          1 |          1 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>   |_fibonacci                                                 |          1 |          2 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>     |_fibonacci                                               |          2 |          3 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>       |_fibonacci                                             |          4 |          4 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>         |_fibonacci                                           |          8 |          5 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>           |_fibonacci                                         |         16 |          6 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>             |_fibonacci                                       |         32 |          7 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>               |_fibonacci                                     |         64 |          8 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                 |_fibonacci                                   |        128 |          9 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
|-------------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>                   |_fibonacci                                 |        254 |         10 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                     |_fibonacci                               |        438 |         11 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                       |_fibonacci                             |        512 |         12 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                         |_fibonacci                           |        352 |         13 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                           |_fibonacci                         |        134 |         14 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                             |_fibonacci                       |         26 |         15 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                               |_fibonacci                     |          2 |         16 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>> |_fibonacci(20)                                               |          1 |          1 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>   |_fibonacci                                                 |          1 |          2 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>     |_fibonacci                                               |          2 |          3 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
|-------------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>       |_fibonacci                                             |          4 |          4 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>         |_fibonacci                                           |          8 |          5 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>           |_fibonacci                                         |         16 |          6 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>             |_fibonacci                                       |         32 |          7 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>               |_fibonacci                                     |         64 |          8 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                 |_fibonacci                                   |        128 |          9 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                   |_fibonacci                                 |        256 |         10 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                     |_fibonacci                               |        512 |         11 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                       |_fibonacci                             |       1024 |         12 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                         |_fibonacci                           |       2026 |         13 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
|-------------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>                           |_fibonacci                         |       3632 |         14 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                             |_fibonacci                       |       5020 |         15 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                               |_fibonacci                     |       4760 |         16 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                                 |_fibonacci                   |       2942 |         17 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                                   |_fibonacci                 |       1152 |         18 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                                     |_fibonacci               |        274 |         19 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                                       |_fibonacci             |         36 |         20 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                                         |_fibonacci           |          2 |         21 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>> |_fibonacci(25)                                               |          1 |          1 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>   |_fibonacci                                                 |          1 |          2 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
|-------------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>     |_fibonacci                                               |          2 |          3 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>       |_fibonacci                                             |          4 |          4 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>         |_fibonacci                                           |          8 |          5 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>           |_fibonacci                                         |         16 |          6 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>             |_fibonacci                                       |         32 |          7 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>               |_fibonacci                                     |         64 |          8 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                 |_fibonacci                                   |        128 |          9 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                   |_fibonacci                                 |        256 |         10 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                     |_fibonacci                               |        512 |         11 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                       |_fibonacci                             |       1024 |         12 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
|-------------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>                         |_fibonacci                           |       2048 |         13 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                           |_fibonacci                         |       4096 |         14 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                             |_fibonacci                       |       8190 |         15 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                               |_fibonacci                     |      16200 |         16 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                                 |_fibonacci                   |      29826 |         17 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                                   |_fibonacci                 |      45638 |         18 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                                     |_fibonacci               |      52666 |         19 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                                       |_fibonacci             |      43556 |         20 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                                         |_fibonacci           |      25232 |         21 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                                           |_fibonacci         |      10072 |         22 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
|-------------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>                                             |_fibonacci       |       2702 |         23 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                                               |_fibonacci     |        464 |         24 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                                                 |_fibonacci   |         46 |         25 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>>                                                   |_fibonacci |          2 |         26 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
| >>> some_func                                                     |          1 |          0 | peak_rss   | KB         |      0.000 |      0.000 |      0.000 |      0.000 |      0.000 |        0.0 |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|

[papi_vector0]|0> Outputting 'timemory-ex-cxx-basic-output/papi_vector0.json'...
[papi_vector0]|0> Outputting 'timemory-ex-cxx-basic-output/papi_vector0.txt'...
Opening 'timemory-ex-cxx-basic-output/papi_vector0_total_cycles.jpeg' for output...
Closed 'timemory-ex-cxx-basic-output/papi_vector0_total_cycles.jpeg'...
Opening 'timemory-ex-cxx-basic-output/papi_vector0_instr_completed.jpeg' for output...
Closed 'timemory-ex-cxx-basic-output/papi_vector0_instr_completed.jpeg'...
Opening 'timemory-ex-cxx-basic-output/papi_vector0_loads_stores_completed.jpeg' for output...
Closed 'timemory-ex-cxx-basic-output/papi_vector0_loads_stores_completed.jpeg'...

|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
|                                                                                  DYNAMICALLY ALLOCATED ARRAY OF PAPI HW COUNTERS                                                                                 |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
|                             LABEL                               | COUNT  | DEPTH  |         METRIC         | UNITS  |      SUM       |      MEAN      |      MIN       |      MAX       |    STDDEV     | % SELF |
|-----------------------------------------------------------------|--------|--------|------------------------|--------|----------------|----------------|----------------|----------------|---------------|--------|
| >>> fibonacci(15)                                               |      1 |      0 | Total_cycles           |        |   30509710.000 |   30509710.000 |   30509710.000 |   30509710.000 |         0.000 |    0.3 |
|                                                                 |        |        | Instr_completed        |        |   37679966.000 |   37679966.000 |   37679966.000 |   37679966.000 |         0.000 |    0.1 |
|                                                                 |        |        | Loads_Stores_completed |        |   20393348.000 |   20393348.000 |   20393348.000 |   20393348.000 |         0.000 |    0.1 |
| >>> |_fibonacci                                                 |      1 |      1 | Total_cycles           |        |   30424245.000 |   30424245.000 |   30424245.000 |   30424245.000 |         0.000 |    0.1 |
|                                                                 |        |        | Instr_completed        |        |   37641555.000 |   37641555.000 |   37641555.000 |   37641555.000 |         0.000 |    0.1 |
|                                                                 |        |        | Loads_Stores_completed |        |   20375321.000 |   20375321.000 |   20375321.000 |   20375321.000 |         0.000 |    0.1 |
| >>>   |_fibonacci                                               |      2 |      2 | Total_cycles           |        |   30382582.000 |   15191291.000 |   11609036.000 |   18773546.000 |   5066073.605 |    0.2 |
|                                                                 |        |        | Instr_completed        |        |   37596467.000 |   18798233.500 |   14286984.000 |   23309483.000 |   6379870.226 |    0.2 |
|                                                                 |        |        | Loads_Stores_completed |        |   20352314.000 |   10176157.000 |    7745353.000 |   12606961.000 |   3437675.984 |    0.2 |
| >>>     |_fibonacci                                             |      4 |      3 | Total_cycles           |        |   30316651.000 |    7579162.750 |    4381732.000 |   11597649.000 |   2983878.812 |    0.4 |
|                                                                 |        |        | Instr_completed        |        |   37515553.000 |    9378888.250 |    5435247.000 |   14448508.000 |   3736632.375 |    0.4 |
|                                                                 |        |        | Loads_Stores_completed |        |   20309758.000 |    5077439.500 |    2946563.000 |    7804705.000 |   2012995.420 |    0.4 |
| >>>       |_fibonacci                                           |      8 |      4 | Total_cycles           |        |   30199565.000 |    3774945.625 |    1652473.000 |    7156084.000 |   1717419.082 |    0.7 |
|                                                                 |        |        | Instr_completed        |        |   37363096.000 |    4670387.000 |    2053673.000 |    8969146.000 |   2149457.490 |    0.8 |
|                                                                 |        |        | Loads_Stores_completed |        |   20228142.000 |    2528517.750 |    1113341.000 |    4835679.000 |   1157685.584 |    0.8 |
| >>>         |_fibonacci                                         |     16 |      5 | Total_cycles           |        |   29975613.000 |    1873475.812 |     616685.000 |    4392367.000 |    971116.707 |    1.5 |
|                                                                 |        |        | Instr_completed        |        |   37067814.000 |    2316738.375 |     761791.000 |    5579449.000 |   1216661.212 |    1.6 |
|                                                                 |        |        | Loads_Stores_completed |        |   20068431.000 |    1254276.938 |     412991.000 |    2999500.000 |    655115.463 |    1.6 |
| >>>           |_fibonacci                                       |     32 |      6 | Total_cycles           |        |   29526039.000 |     922688.719 |     212656.000 |    2780251.000 |    547293.580 |    2.9 |
|                                                                 |        |        | Instr_completed        |        |   36485304.000 |    1140165.750 |     267898.000 |    3481326.000 |    679110.953 |    3.2 |
|                                                                 |        |        | Loads_Stores_completed |        |   19752324.000 |     617260.125 |     145216.000 |    1863593.000 |    365560.903 |    3.2 |
| >>>             |_fibonacci                                     |     64 |      7 | Total_cycles           |        |   28656737.000 |     447761.516 |      62169.000 |    1784210.000 |    304433.036 |    6.1 |
|                                                                 |        |        | Instr_completed        |        |   35331987.000 |     552062.297 |      78100.000 |    2180882.000 |    374611.546 |    6.5 |
|                                                                 |        |        | Loads_Stores_completed |        |   19123910.000 |     298811.094 |      42258.000 |    1160183.000 |    201582.104 |    6.6 |
| >>>               |_fibonacci                                   |    128 |      8 | Total_cycles           |        |   26912024.000 |     210250.188 |       2347.000 |    1163791.000 |    167371.088 |   13.1 |
|                                                                 |        |        | Instr_completed        |        |   33034604.000 |     258082.844 |       2299.000 |    1374071.000 |    204634.242 |   13.8 |
|                                                                 |        |        | Loads_Stores_completed |        |   17870542.000 |     139613.609 |       1107.000 |     724456.000 |    110071.008 |   13.9 |
| >>>                 |_fibonacci                                 |    254 |      9 | Total_cycles           |        |   23388502.000 |      92080.717 |       1797.000 |     774569.000 |     91350.448 |   27.0 |
|                                                                 |        |        | Instr_completed        |        |   28482823.000 |     112137.098 |       2067.000 |     870992.000 |    110777.745 |   27.9 |
|                                                                 |        |        | Loads_Stores_completed |        |   15385766.000 |      60573.882 |       1005.000 |     453443.000 |     59554.011 |   28.1 |
|-----------------------------------------------------------------|--------|--------|------------------------|--------|----------------|----------------|----------------|----------------|---------------|--------|
| >>>                   |_fibonacci                               |    438 |     10 | Total_cycles           |        |   17065844.000 |      38963.114 |       1695.000 |     527534.000 |     50039.644 |   45.5 |
|                                                                 |        |        | Instr_completed        |        |   20534236.000 |      46881.817 |       2067.000 |     557016.000 |     59836.439 |   46.6 |
|                                                                 |        |        | Loads_Stores_completed |        |   11063242.000 |      25258.543 |       1005.000 |     285087.000 |     32115.270 |   47.0 |
| >>>                     |_fibonacci                             |    512 |     11 | Total_cycles           |        |    9293767.000 |      18151.889 |       1643.000 |     366802.000 |     29613.260 |   62.2 |
|                                                                 |        |        | Instr_completed        |        |   10960715.000 |      21407.646 |       2067.000 |     355772.000 |     34225.376 |   64.2 |
|                                                                 |        |        | Loads_Stores_completed |        |    5864194.000 |      11453.504 |       1005.000 |     177979.000 |     18272.997 |   64.8 |
| >>>                       |_fibonacci                           |    352 |     12 | Total_cycles           |        |    3515764.000 |       9987.966 |       1670.000 |     258761.000 |     20366.377 |   75.7 |
|                                                                 |        |        | Instr_completed        |        |    3921365.000 |      11140.241 |       2067.000 |     228845.000 |     21752.265 |   77.2 |
|                                                                 |        |        | Loads_Stores_completed |        |    2065663.000 |       5868.361 |       1005.000 |     111402.000 |     11427.139 |   78.0 |
| >>>                         |_fibonacci                         |    134 |     13 | Total_cycles           |        |     855879.000 |       6387.157 |       1785.000 |     184074.000 |     17901.177 |   77.1 |
|                                                                 |        |        | Instr_completed        |        |     895459.000 |       6682.530 |       2067.000 |     142238.000 |     16143.343 |   83.2 |
|                                                                 |        |        | Loads_Stores_completed |        |     455074.000 |       3396.075 |       1005.000 |      66326.000 |      8060.515 |   85.0 |
| >>>                           |_fibonacci                       |     26 |     14 | Total_cycles           |        |     195907.000 |       7534.885 |       1947.000 |     141364.000 |     27296.253 |   90.9 |
|                                                                 |        |        | Instr_completed        |        |     150182.000 |       5776.231 |       2067.000 |      95411.000 |     18282.058 |   92.7 |
|                                                                 |        |        | Loads_Stores_completed |        |      68436.000 |       2632.154 |       1005.000 |      42411.000 |      8113.336 |   93.2 |
| >>>                             |_fibonacci                     |      2 |     15 | Total_cycles           |        |      17804.000 |       8902.000 |       4341.000 |      13463.000 |      6450.228 |    0.0 |
|                                                                 |        |        | Instr_completed        |        |      10988.000 |       5494.000 |       2245.000 |       8743.000 |      4594.780 |    0.0 |
|                                                                 |        |        | Loads_Stores_completed |        |       4624.000 |       2312.000 |       1054.000 |       3570.000 |      1779.081 |    0.0 |
| >>> fibonacci(20)                                               |      1 |      0 | Total_cycles           |        |  328681214.000 |  328681214.000 |  328681214.000 |  328681214.000 |         0.000 |    0.0 |
|                                                                 |        |        | Instr_completed        |        |  415768604.000 |  415768604.000 |  415768604.000 |  415768604.000 |         0.000 |    0.0 |
|                                                                 |        |        | Loads_Stores_completed |        |  225386036.000 |  225386036.000 |  225386036.000 |  225386036.000 |         0.000 |    0.0 |
| >>> |_fibonacci                                                 |      1 |      1 | Total_cycles           |        |  328647537.000 |  328647537.000 |  328647537.000 |  328647537.000 |         0.000 |    0.0 |
|                                                                 |        |        | Instr_completed        |        |  415746396.000 |  415746396.000 |  415746396.000 |  415746396.000 |         0.000 |    0.0 |
|                                                                 |        |        | Loads_Stores_completed |        |  225374279.000 |  225374279.000 |  225374279.000 |  225374279.000 |         0.000 |    0.0 |
| >>>   |_fibonacci                                               |      2 |      2 | Total_cycles           |        |  328610834.000 |  164305417.000 |  123117948.000 |  205492886.000 |  58247877.260 |    0.0 |
|                                                                 |        |        | Instr_completed        |        |  415707532.000 |  207853766.000 |  158773409.000 |  256934123.000 |  69410106.516 |    0.0 |
|                                                                 |        |        | Loads_Stores_completed |        |  225353357.000 |  112676678.500 |   86057285.000 |  139296072.000 |  37645507.310 |    0.0 |
| >>>     |_fibonacci                                             |      4 |      3 | Total_cycles           |        |  328547787.000 |   82136946.750 |   47193027.000 |  128797733.000 |  33996275.417 |    0.1 |
|                                                                 |        |        | Instr_completed        |        |  415632802.000 |  103908200.500 |   60637471.000 |  158795271.000 |  40630104.720 |    0.1 |
|                                                                 |        |        | Loads_Stores_completed |        |  225312885.000 |   56328221.250 |   32858471.000 |   86095916.000 |  22036158.770 |    0.1 |
|-----------------------------------------------------------------|--------|--------|------------------------|--------|----------------|----------------|----------------|----------------|---------------|--------|
| >>>       |_fibonacci                                           |      8 |      4 | Total_cycles           |        |  328432200.000 |   41054025.000 |   18033870.000 |   80441907.000 |  19402219.559 |    0.1 |
|                                                                 |        |        | Instr_completed        |        |  415486621.000 |   51935827.625 |   23145020.000 |   98148947.000 |  23357778.731 |    0.1 |
|                                                                 |        |        | Loads_Stores_completed |        |  225233362.000 |   28154170.250 |   12538886.000 |   53215343.000 |  12668218.827 |    0.1 |
| >>>         |_fibonacci                                         |     16 |      5 | Total_cycles           |        |  328204754.000 |   20512797.125 |    6877604.000 |   50171720.000 |  10905281.230 |    0.3 |
|                                                                 |        |        | Instr_completed        |        |  415197641.000 |   25949852.562 |    8820935.000 |   60670987.000 |  13212544.364 |    0.3 |
|                                                                 |        |        | Loads_Stores_completed |        |  225075748.000 |   14067234.250 |    4777679.000 |   32893150.000 |   7165806.190 |    0.3 |
| >>>           |_fibonacci                                       |     32 |      6 | Total_cycles           |        |  327751582.000 |   10242236.938 |    2609198.000 |   31231117.000 |   6045969.675 |    0.5 |
|                                                                 |        |        | Instr_completed        |        |  414621434.000 |   12956919.812 |    3348301.000 |   37509815.000 |   7369609.296 |    0.6 |
|                                                                 |        |        | Loads_Stores_completed |        |  224761743.000 |    7023804.469 |    1813157.000 |   20332635.000 |   3996832.509 |    0.6 |
| >>>             |_fibonacci                                     |     64 |      7 | Total_cycles           |        |  326867800.000 |    5107309.375 |     978773.000 |   19519714.000 |   3320879.846 |    1.1 |
|                                                                 |        |        | Instr_completed        |        |  413474419.000 |    6460537.797 |    1257507.000 |   23195820.000 |   4062002.534 |    1.1 |
|                                                                 |        |        | Loads_Stores_completed |        |  224135426.000 |    3502116.031 |     680781.000 |   12569261.000 |   2202940.283 |    1.1 |
| >>>               |_fibonacci                                   |    128 |      8 | Total_cycles           |        |  325100795.000 |    2539849.961 |     352436.000 |   12122994.000 |   1805172.337 |    2.2 |
|                                                                 |        |        | Instr_completed        |        |  411183355.000 |    3212369.961 |     458908.000 |   14348807.000 |   2216833.772 |    2.3 |
|                                                                 |        |        | Loads_Stores_completed |        |  222884158.000 |    1741282.484 |     248316.000 |    7770675.000 |   1202221.379 |    2.3 |
| >>>                 |_fibonacci                                 |    256 |      9 | Total_cycles           |        |  321578081.000 |    1256164.379 |     118981.000 |    7515114.000 |    973391.639 |    4.5 |
|                                                                 |        |        | Instr_completed        |        |  406594211.000 |    1588258.637 |     154480.000 |    8880199.000 |   1199966.091 |    4.6 |
|                                                                 |        |        | Loads_Stores_completed |        |  220381468.000 |     860865.109 |      83494.000 |    4804508.000 |    650738.305 |    4.6 |
| >>>                   |_fibonacci                               |    512 |     10 | Total_cycles           |        |  314452973.000 |     614165.963 |      31331.000 |    4662643.000 |    521644.030 |    9.2 |
|                                                                 |        |        | Instr_completed        |        |  397386123.000 |     776144.771 |      40154.000 |    5499112.000 |    645164.670 |    9.6 |
|                                                                 |        |        | Loads_Stores_completed |        |  215372858.000 |     420650.113 |      21634.000 |    2970740.000 |    349857.392 |    9.6 |
| >>>                     |_fibonacci                             |   1024 |     11 | Total_cycles           |        |  300453008.000 |     293411.141 |       1789.000 |    2904983.000 |    278217.446 |   19.0 |
|                                                                 |        |        | Instr_completed        |        |  379011238.000 |     370128.162 |       2067.000 |    3407957.000 |    344940.831 |   19.1 |
|                                                                 |        |        | Loads_Stores_completed |        |  205362000.000 |     200548.828 |       1005.000 |    1836897.000 |    187045.873 |   19.2 |
| >>>                       |_fibonacci                           |   2026 |     12 | Total_cycles           |        |  272818916.000 |     134658.892 |       1645.000 |    1813647.000 |    147834.513 |   32.4 |
|                                                                 |        |        | Instr_completed        |        |  342635835.000 |     169119.366 |       2067.000 |    2113152.000 |    183570.364 |   33.3 |
|                                                                 |        |        | Loads_Stores_completed |        |  185545124.000 |      91581.996 |       1005.000 |    1135256.000 |     99538.480 |   33.5 |
| >>>                         |_fibonacci                         |   3632 |     13 | Total_cycles           |        |  220968345.000 |      60839.302 |       1631.000 |    1136699.000 |     79189.908 |   48.1 |
|                                                                 |        |        | Instr_completed        |        |  277271957.000 |      76341.398 |       2067.000 |    1311693.000 |     98429.546 |   49.1 |
|                                                                 |        |        | Loads_Stores_completed |        |  149939146.000 |      41282.805 |       1005.000 |     701282.000 |     53370.103 |   49.4 |
|-----------------------------------------------------------------|--------|--------|------------------------|--------|----------------|----------------|----------------|----------------|---------------|--------|
| >>>                           |_fibonacci                       |   5020 |     14 | Total_cycles           |        |  149421139.000 |      29765.167 |       1648.000 |     719047.000 |     44765.164 |   62.3 |
|                                                                 |        |        | Instr_completed        |        |  184899000.000 |      36832.470 |       2067.000 |     813735.000 |     55364.013 |   63.6 |
|                                                                 |        |        | Loads_Stores_completed |        |   99702887.000 |      19861.133 |       1005.000 |     431975.000 |     30015.917 |   63.9 |
| >>>                             |_fibonacci                     |   4760 |     15 | Total_cycles           |        |   77616377.000 |      16305.962 |       1599.000 |     456616.000 |     27571.501 |   73.8 |
|                                                                 |        |        | Instr_completed        |        |   94041780.000 |      19756.676 |       2067.000 |     505529.000 |     33695.273 |   75.3 |
|                                                                 |        |        | Loads_Stores_completed |        |   50419341.000 |      10592.299 |       1005.000 |     265600.000 |     18256.260 |   75.6 |
| >>>                               |_fibonacci                   |   2942 |     16 | Total_cycles           |        |   29292896.000 |       9956.797 |       1650.000 |     282925.000 |     18466.523 |   83.2 |
|                                                                 |        |        | Instr_completed        |        |   34252479.000 |      11642.583 |       2067.000 |     306579.000 |     22088.628 |   84.1 |
|                                                                 |        |        | Loads_Stores_completed |        |   18199791.000 |       6186.197 |       1005.000 |     159312.000 |     11948.670 |   84.5 |
| >>>                                 |_fibonacci                 |   1152 |     17 | Total_cycles           |        |    7677143.000 |       6664.187 |       1685.000 |     175872.000 |     13266.341 |   88.7 |
|                                                                 |        |        | Instr_completed        |        |    8476878.000 |       7358.401 |       2067.000 |     182911.000 |     15244.953 |   90.6 |
|                                                                 |        |        | Loads_Stores_completed |        |    4440168.000 |       3854.312 |       1005.000 |      94009.000 |      8204.443 |   91.0 |
| >>>                                   |_fibonacci               |    274 |     18 | Total_cycles           |        |    1287383.000 |       4698.478 |       1753.000 |     102286.000 |      9983.232 |   94.7 |
|                                                                 |        |        | Instr_completed        |        |    1348015.000 |       4919.763 |       2067.000 |      97476.000 |     10842.477 |   96.0 |
|                                                                 |        |        | Loads_Stores_completed |        |     689311.000 |       2515.734 |       1005.000 |      49393.000 |      5739.372 |   96.2 |
| >>>                                     |_fibonacci             |     36 |     19 | Total_cycles           |        |     145264.000 |       4035.111 |       2096.000 |      60655.000 |      9707.566 |    0.0 |
|                                                                 |        |        | Instr_completed        |        |     127278.000 |       3535.500 |       2067.000 |      50547.000 |      8059.288 |    0.0 |
|                                                                 |        |        | Loads_Stores_completed |        |      61889.000 |       1719.139 |       1005.000 |      25439.000 |      4066.283 |    0.0 |
| >>>                                       |_fibonacci           |      2 |     20 | Total_cycles           |        |       7667.000 |       3833.500 |       3144.000 |       4523.000 |       975.100 |    0.0 |
|                                                                 |        |        | Instr_completed        |        |       5051.000 |       2525.500 |       2245.000 |       2806.000 |       396.687 |    0.0 |
|                                                                 |        |        | Loads_Stores_completed |        |       2349.000 |       1174.500 |       1054.000 |       1295.000 |       170.413 |    0.0 |
| >>> fibonacci(25)                                               |      1 |      0 | Total_cycles           |        | 3534498162.000 | 3534498162.000 | 3534498162.000 | 3534498162.000 |         0.000 |    0.0 |
|                                                                 |        |        | Instr_completed        |        | 4610100460.000 | 4610100460.000 | 4610100460.000 | 4610100460.000 |         0.000 |    0.0 |
|                                                                 |        |        | Loads_Stores_completed |        | 2499648473.000 | 2499648473.000 | 2499648473.000 | 2499648473.000 |         0.000 |    0.0 |
| >>> |_fibonacci                                                 |      1 |      1 | Total_cycles           |        | 3534469431.000 | 3534469431.000 | 3534469431.000 | 3534469431.000 |         0.000 |    0.0 |
|                                                                 |        |        | Instr_completed        |        | 4610078139.000 | 4610078139.000 | 4610078139.000 | 4610078139.000 |         0.000 |    0.0 |
|                                                                 |        |        | Loads_Stores_completed |        | 2499636694.000 | 2499636694.000 | 2499636694.000 | 2499636694.000 |         0.000 |    0.0 |
| >>>   |_fibonacci                                               |      2 |      2 | Total_cycles           |        | 3534436968.000 | 1767218484.000 | 1353521929.000 | 2180915039.000 | 585055278.788 |    0.0 |
|                                                                 |        |        | Instr_completed        |        | 4610039390.000 | 2305019695.000 | 1761028293.000 | 2849011097.000 | 769320018.523 |    0.0 |
|                                                                 |        |        | Loads_Stores_completed |        | 2499615788.000 | 1249807894.000 |  954768238.000 | 1544847550.000 | 417249082.953 |    0.0 |
|-----------------------------------------------------------------|--------|--------|------------------------|--------|----------------|----------------|----------------|----------------|---------------|--------|
| >>>     |_fibonacci                                             |      4 |      3 | Total_cycles           |        | 3534375122.000 |  883593780.500 |  517135518.000 | 1348321295.000 | 344044065.936 |    0.0 |
|                                                                 |        |        | Instr_completed        |        | 4609964737.000 | 1152491184.250 |  672706094.000 | 1760685921.000 | 450310666.575 |    0.0 |
|                                                                 |        |        | Loads_Stores_completed |        | 2499575323.000 |  624893830.750 |  364688018.000 |  954765957.000 | 244233073.302 |    0.0 |
| >>>       |_fibonacci                                           |      8 |      4 | Total_cycles           |        | 3534260429.000 |  441782553.625 |  197537579.000 |  834357111.000 | 198122528.148 |    0.0 |
|                                                                 |        |        | Instr_completed        |        | 4609818556.000 |  576227319.500 |  256951249.000 | 1088111122.000 | 258864368.020 |    0.0 |
|                                                                 |        |        | Loads_Stores_completed |        | 2499495800.000 |  312436975.000 |  139290657.000 |  590081676.000 | 140400905.481 |    0.0 |
| >>>         |_fibonacci                                         |     16 |      5 | Total_cycles           |        | 3534039021.000 |  220877438.812 |   75393591.000 |  517445415.000 | 112232426.759 |    0.0 |
|                                                                 |        |        | Instr_completed        |        | 4609528969.000 |  288095560.562 |   98129367.000 |  672473806.000 | 146421036.655 |    0.0 |
|                                                                 |        |        | Loads_Stores_completed |        | 2499338111.000 |  156208631.938 |   53193267.000 |  364697405.000 |  79415335.504 |    0.1 |
| >>>           |_fibonacci                                       |     32 |      6 | Total_cycles           |        | 3533597967.000 |  110424936.469 |   28754120.000 |  320479998.000 |  62597176.765 |    0.1 |
|                                                                 |        |        | Instr_completed        |        | 4608953977.000 |  144029811.781 |   37461068.000 |  415615973.000 |  81664885.668 |    0.1 |
|                                                                 |        |        | Loads_Stores_completed |        | 2499024259.000 |   78094508.094 |   20305874.000 |  225404131.000 |  44293494.818 |    0.1 |
| >>>             |_fibonacci                                     |     64 |      7 | Total_cycles           |        | 3532734516.000 |   55198976.812 |   10965125.000 |  197907024.000 |  34479753.217 |    0.2 |
|                                                                 |        |        | Instr_completed        |        | 4607806961.000 |   71996983.766 |   14283735.000 |  256879423.000 |  45009322.578 |    0.2 |
|                                                                 |        |        | Loads_Stores_completed |        | 2498397937.000 |   39037467.766 |    7743811.000 |  139315208.000 |  24412357.247 |    0.2 |
| >>>               |_fibonacci                                   |    128 |      8 | Total_cycles           |        | 3531001022.000 |   27585945.484 |    4189334.000 |  122083288.000 |  18810140.841 |    0.4 |
|                                                                 |        |        | Instr_completed        |        | 4605515895.000 |   35980592.930 |    5433241.000 |  158778987.000 |  24562002.516 |    0.4 |
|                                                                 |        |        | Loads_Stores_completed |        | 2497146676.000 |   19508958.406 |    2945597.000 |   86108463.000 |  13322122.103 |    0.4 |
| >>>                 |_fibonacci                                 |    256 |      9 | Total_cycles           |        | 3527515717.000 |   13779358.270 |    1596071.000 |   75461876.000 |  10173060.157 |    0.8 |
|                                                                 |        |        | Instr_completed        |        | 4600926959.000 |   17972370.934 |    2052961.000 |   98150217.000 |  13294274.579 |    0.8 |
|                                                                 |        |        | Loads_Stores_completed |        | 2494644234.000 |    9744704.039 |    1112891.000 |   53223906.000 |   7210688.548 |    0.8 |
| >>>                   |_fibonacci                               |    512 |     10 | Total_cycles           |        | 3520611524.000 |    6876194.383 |     601781.000 |   46627931.000 |   5468042.653 |    1.7 |
|                                                                 |        |        | Instr_completed        |        | 4591771521.000 |    8968303.752 |     761755.000 |   60678699.000 |   7147058.364 |    1.6 |
|                                                                 |        |        | Loads_Stores_completed |        | 2489643294.000 |    4862584.559 |     412811.000 |   32899196.000 |   3876510.706 |    1.6 |
| >>>                     |_fibonacci                             |   1024 |     11 | Total_cycles           |        | 3506938884.000 |    3424745.004 |     211619.000 |   28820338.000 |   2922037.112 |    3.2 |
|                                                                 |        |        | Instr_completed        |        | 4573463631.000 |    4466273.077 |     268058.000 |   37518487.000 |   3820841.758 |    3.3 |
|                                                                 |        |        | Loads_Stores_completed |        | 2479642786.000 |    2421526.158 |     145150.000 |   20337009.000 |   2072401.535 |    3.3 |
| >>>                       |_fibonacci                           |   2048 |     12 | Total_cycles           |        | 3479805422.000 |    1699123.741 |      62537.000 |   17839260.000 |   1554419.386 |    6.5 |
|                                                                 |        |        | Instr_completed        |        | 4536850932.000 |    2215259.244 |      78192.000 |   23203155.000 |   2033144.248 |    6.7 |
|                                                                 |        |        | Loads_Stores_completed |        | 2459643172.000 |    1200997.643 |      42226.000 |   12572467.000 |   1102766.816 |    6.8 |
|-----------------------------------------------------------------|--------|--------|------------------------|--------|----------------|----------------|----------------|----------------|---------------|--------|
| >>>                         |_fibonacci                         |   4096 |     13 | Total_cycles           |        | 3421050204.000 |     835217.335 |       2333.000 |   11080149.000 |    823810.167 |   12.8 |
|                                                                 |        |        | Instr_completed        |        | 4463599959.000 |    1089746.084 |       2299.000 |   14354338.000 |   1077659.412 |   13.3 |
|                                                                 |        |        | Loads_Stores_completed |        | 2419735430.000 |     590755.720 |       1107.000 |    7773099.000 |    584517.152 |   13.4 |
| >>>                           |_fibonacci                       |   8190 |     14 | Total_cycles           |        | 3310992345.000 |     404272.570 |       1644.000 |    6870766.000 |    435060.394 |   23.5 |
|                                                                 |        |        | Instr_completed        |        | 4316872387.000 |     527090.646 |       2067.000 |    8884256.000 |    569334.833 |   23.9 |
|                                                                 |        |        | Loads_Stores_completed |        | 2339710479.000 |     285678.935 |       1005.000 |    4806373.000 |    308804.040 |   24.0 |
| >>>                             |_fibonacci                     |  16200 |     15 | Total_cycles           |        | 3094586848.000 |     191023.880 |       1636.000 |    4267313.000 |    229401.615 |   37.0 |
|                                                                 |        |        | Instr_completed        |        | 4026667630.000 |     248559.730 |       2067.000 |    5502153.000 |    300323.603 |   37.0 |
|                                                                 |        |        | Loads_Stores_completed |        | 2181360312.000 |     134651.871 |       1005.000 |    2972229.000 |    162893.927 |   37.2 |
| >>>                               |_fibonacci                   |  29826 |     16 | Total_cycles           |        | 2698275418.000 |      90467.224 |       1603.000 |    2653575.000 |    122379.953 |   49.7 |
|                                                                 |        |        | Instr_completed        |        | 3490720637.000 |     117036.164 |       2067.000 |    3409746.000 |    160217.251 |   50.6 |
|                                                                 |        |        | Loads_Stores_completed |        | 1888752841.000 |      63325.717 |       1005.000 |    1837954.000 |     86902.566 |   50.9 |
| >>>                                 |_fibonacci                 |  45638 |     17 | Total_cycles           |        | 2063559168.000 |      45215.811 |       1653.000 |    1654791.000 |     68178.268 |   61.8 |
|                                                                 |        |        | Instr_completed        |        | 2656155093.000 |      58200.515 |       2067.000 |    2114583.000 |     89225.143 |   62.8 |
|                                                                 |        |        | Loads_Stores_completed |        | 1435173970.000 |      31446.908 |       1005.000 |    1136129.000 |     48400.791 |   63.1 |
| >>>                                   |_fibonacci               |  52666 |     18 | Total_cycles           |        | 1300287688.000 |      24689.319 |       1605.000 |    1038997.000 |     40847.577 |   72.7 |
|                                                                 |        |        | Instr_completed        |        | 1672387441.000 |      31754.594 |       2067.000 |    1313038.000 |     53364.405 |   73.0 |
|                                                                 |        |        | Loads_Stores_completed |        |  900838683.000 |      17104.748 |       1004.000 |     702025.000 |     28948.254 |   73.2 |
| >>>                                     |_fibonacci             |  43556 |     19 | Total_cycles           |        |  653912139.000 |      15013.136 |       1595.000 |     656732.000 |     26529.344 |   80.7 |
|                                                                 |        |        | Instr_completed        |        |  826307632.000 |      18971.155 |       2067.000 |     815132.000 |     34454.264 |   81.1 |
|                                                                 |        |        | Loads_Stores_completed |        |  442755820.000 |      10165.208 |       1001.000 |     432652.000 |     18686.349 |   81.4 |
| >>>                                       |_fibonacci           |  25232 |     20 | Total_cycles           |        |  249494318.000 |       9888.012 |       1645.000 |     419549.000 |     18342.376 |   86.9 |
|                                                                 |        |        | Instr_completed        |        |  307625363.000 |      12191.874 |       2067.000 |     506945.000 |     23713.003 |   87.5 |
|                                                                 |        |        | Loads_Stores_completed |        |  163565143.000 |       6482.449 |        998.000 |     266220.000 |     12854.011 |   87.8 |
| >>>                                         |_fibonacci         |  10072 |     21 | Total_cycles           |        |   68059799.000 |       6757.327 |       1690.000 |     259089.000 |     13118.837 |   91.4 |
|                                                                 |        |        | Instr_completed        |        |   83031707.000 |       8243.815 |       2067.000 |     307459.000 |     17014.942 |   92.4 |
|                                                                 |        |        | Loads_Stores_completed |        |   43761981.000 |       4344.915 |       1003.000 |     159731.000 |      9222.590 |   92.7 |
| >>>                                           |_fibonacci       |   2702 |     22 | Total_cycles           |        |   13141526.000 |       4863.629 |       1670.000 |     158075.000 |      9738.971 |   95.5 |
|                                                                 |        |        | Instr_completed        |        |   15655471.000 |       5794.031 |       2067.000 |     182931.000 |     12483.947 |   96.6 |
|                                                                 |        |        | Loads_Stores_completed |        |    8140045.000 |       3012.600 |       1005.000 |      94029.000 |      6742.892 |   96.8 |
|-----------------------------------------------------------------|--------|--------|------------------------|--------|----------------|----------------|----------------|----------------|---------------|--------|
| >>>                                             |_fibonacci     |    464 |     23 | Total_cycles           |        |    1726414.000 |       3720.720 |       1723.000 |      90385.000 |      7612.110 |    0.3 |
|                                                                 |        |        | Instr_completed        |        |    1955525.000 |       4214.494 |       2067.000 |      97551.000 |      9250.880 |    0.1 |
|                                                                 |        |        | Loads_Stores_completed |        |     993411.000 |       2140.972 |       1005.000 |      49398.000 |      4909.853 |    0.1 |
| >>>                                               |_fibonacci   |     46 |     24 | Total_cycles           |        |     148243.000 |       3222.674 |       1978.000 |      52242.000 |      7388.471 |    0.1 |
|                                                                 |        |        | Instr_completed        |        |     149313.000 |       3245.935 |       2067.000 |      50622.000 |      7140.637 |    0.1 |
|                                                                 |        |        | Loads_Stores_completed |        |      72319.000 |       1572.152 |       1005.000 |      25444.000 |      3597.950 |    0.1 |
| >>>                                                 |_fibonacci |      2 |     25 | Total_cycles           |        |       6702.000 |       3351.000 |       2793.000 |       3909.000 |       789.131 |    0.2 |
|                                                                 |        |        | Instr_completed        |        |       5051.000 |       2525.500 |       2245.000 |       2806.000 |       396.687 |    0.2 |
|                                                                 |        |        | Loads_Stores_completed |        |       2349.000 |       1174.500 |       1054.000 |       1295.000 |       170.413 |    0.2 |
| >>> some_func                                                   |      1 |      0 | Total_cycles           |        |      15574.000 |      15574.000 |      15574.000 |      15574.000 |         0.000 |    0.4 |
|                                                                 |        |        | Instr_completed        |        |       2948.000 |       2948.000 |       2948.000 |       2948.000 |         0.000 |    0.4 |
|                                                                 |        |        | Loads_Stores_completed |        |       1396.000 |       1396.000 |       1396.000 |       1396.000 |         0.000 |    0.4 |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|

[cpu_util]|0> Outputting 'timemory-ex-cxx-basic-output/cpu_util.json'...
[cpu_util]|0> Outputting 'timemory-ex-cxx-basic-output/cpu_util.txt'...
Opening 'timemory-ex-cxx-basic-output/cpu_util.jpeg' for output...
Closed 'timemory-ex-cxx-basic-output/cpu_util.jpeg'...

|-------------------------------------------------------------------------------------------------------------------------------------------------------------|
|                                                    PERCENTAGE OF CPU-CLOCK TIME DIVIDED BY WALL-CLOCK TIME                                                  |
|-------------------------------------------------------------------------------------------------------------------------------------------------------------|
|                              LABEL                                | COUNT | DEPTH | METRIC   | UNITS |  SUM   | MEAN  | MIN   |   MAX    | STDDEV  | % SELF |
|-------------------------------------------------------------------|-------|-------|----------|-------|--------|-------|-------|----------|---------|--------|
| >>> ex_cxx_basic                                                  |     1 |     0 | cpu_util | %     |   97.4 |  97.4 |  97.4 |     97.4 |     0.0 |    0.0 |
| >>> |_fibonacci(15)                                               |     1 |     1 | cpu_util | %     |   64.9 |  64.9 |  64.9 |     64.9 |     0.0 |    0.0 |
| >>>   |_fibonacci                                                 |     1 |     2 | cpu_util | %     |   65.2 |  65.2 |  65.2 |     65.2 |     0.0 |    0.0 |
| >>>     |_fibonacci                                               |     2 |     3 | cpu_util | %     |   65.3 |  32.7 |   0.0 |     99.8 |    70.6 |    0.0 |
| >>>       |_fibonacci                                             |     4 |     4 | cpu_util | %     |   65.5 |  16.4 |   0.0 |    148.3 |    74.1 |    0.0 |
| >>>         |_fibonacci                                           |     8 |     5 | cpu_util | %     |   65.7 |   8.2 |   0.0 |    211.7 |    74.9 |    0.0 |
| >>>           |_fibonacci                                         |    16 |     6 | cpu_util | %     |   66.2 |   4.1 |   0.0 |    291.2 |    72.8 |    0.0 |
| >>>             |_fibonacci                                       |    32 |     7 | cpu_util | %     |   67.1 |   2.1 |   0.0 |    463.9 |    82.0 |    0.0 |
| >>>               |_fibonacci                                     |    64 |     8 | cpu_util | %     |   68.9 |   1.1 |   0.0 |    728.0 |    91.0 |    0.0 |
| >>>                 |_fibonacci                                   |   128 |     9 | cpu_util | %     |   72.8 |   0.6 |   0.0 |   1128.7 |    99.8 |    0.0 |
|-------------------------------------------------------------------|-------|-------|----------|-------|--------|-------|-------|----------|---------|--------|
| >>>                   |_fibonacci                                 |   254 |    10 | cpu_util | %     |   82.3 |   0.3 |   0.0 |   1723.7 |   108.2 |  100.0 |
| >>>                     |_fibonacci                               |   438 |    11 | cpu_util | %     |    0.0 |   0.0 |   0.0 |      0.0 |     0.0 |    0.0 |
| >>>                       |_fibonacci                             |   512 |    12 | cpu_util | %     |    0.0 |   0.0 |   0.0 |      0.0 |     0.0 |    0.0 |
| >>>                         |_fibonacci                           |   352 |    13 | cpu_util | %     |    0.0 |   0.0 |   0.0 |      0.0 |     0.0 |    0.0 |
| >>>                           |_fibonacci                         |   134 |    14 | cpu_util | %     |    0.0 |   0.0 |   0.0 |      0.0 |     0.0 |    0.0 |
| >>>                             |_fibonacci                       |    26 |    15 | cpu_util | %     |    0.0 |   0.0 |   0.0 |      0.0 |     0.0 |    0.0 |
| >>>                               |_fibonacci                     |     2 |    16 | cpu_util | %     |    0.0 |   0.0 |   0.0 |      0.0 |     0.0 |    0.0 |
| >>> |_fibonacci(20)                                               |     1 |     1 | cpu_util | %     |  104.2 | 104.2 | 104.2 |    104.2 |     0.0 |    0.0 |
| >>>   |_fibonacci                                                 |     1 |     2 | cpu_util | %     |  104.2 | 104.2 | 104.2 |    104.2 |     0.0 |    0.0 |
| >>>     |_fibonacci                                               |     2 |     3 | cpu_util | %     |  104.2 |  52.1 |  92.7 |    111.1 |    13.0 |    0.0 |
|-------------------------------------------------------------------|-------|-------|----------|-------|--------|-------|-------|----------|---------|--------|
| >>>       |_fibonacci                                             |     4 |     4 | cpu_util | %     |  104.2 |  26.0 |  89.1 |    124.2 |    16.4 |    0.0 |
| >>>         |_fibonacci                                           |     8 |     5 | cpu_util | %     |  104.2 |  13.0 |  48.0 |    156.2 |    36.3 |    0.0 |
| >>>           |_fibonacci                                         |    16 |     6 | cpu_util | %     |  104.3 |   6.5 |   0.0 |    249.1 |    77.7 |    0.0 |
| >>>             |_fibonacci                                       |    32 |     7 | cpu_util | %     |  104.4 |   3.3 |   0.0 |    532.5 |   132.3 |    0.0 |
| >>>               |_fibonacci                                     |    64 |     8 | cpu_util | %     |  104.7 |   1.6 |   0.0 |   1426.9 |   261.8 |    0.0 |
| >>>                 |_fibonacci                                   |   128 |     9 | cpu_util | %     |  105.2 |   0.8 |   0.0 |   3851.4 |   494.1 |    0.0 |
| >>>                   |_fibonacci                                 |   256 |    10 | cpu_util | %     |  106.3 |   0.4 |   0.0 |  10901.6 |   903.6 |    0.0 |
| >>>                     |_fibonacci                               |   512 |    11 | cpu_util | %     |  108.5 |   0.2 |   0.0 |  18865.4 |  1169.1 |   16.5 |
| >>>                       |_fibonacci                             |  1024 |    12 | cpu_util | %     |   90.6 |   0.1 |   0.0 |  36292.4 |  1563.5 |    0.0 |
| >>>                         |_fibonacci                           |  2026 |    13 | cpu_util | %     |   90.8 |   0.0 |   0.0 |  67385.4 |  2388.9 |   33.9 |
|-------------------------------------------------------------------|-------|-------|----------|-------|--------|-------|-------|----------|---------|--------|
| >>>                           |_fibonacci                         |  3632 |    14 | cpu_util | %     |   60.0 |   0.0 |   0.0 |  68418.2 |  2050.5 |    4.4 |
| >>>                             |_fibonacci                       |  5020 |    15 | cpu_util | %     |   57.4 |   0.0 |   0.0 | 586510.3 |  8344.6 |    8.2 |
| >>>                               |_fibonacci                     |  4760 |    16 | cpu_util | %     |   52.7 |   0.0 |   0.0 |  65958.7 |   958.9 |    0.0 |
| >>>                                 |_fibonacci                   |  2942 |    17 | cpu_util | %     |  130.9 |   0.0 |   0.0 | 557724.5 | 10283.6 |    0.0 |
| >>>                                   |_fibonacci                 |  1152 |    18 | cpu_util | %     |  233.9 |   0.2 |   0.0 |  13437.1 |   395.9 |    0.0 |
| >>>                                     |_fibonacci               |   274 |    19 | cpu_util | %     | 1278.1 |   4.7 |   0.0 |  62251.0 |  3760.7 |  100.0 |
| >>>                                       |_fibonacci             |    36 |    20 | cpu_util | %     |    0.0 |   0.0 |   0.0 |      0.0 |     0.0 |    0.0 |
| >>>                                         |_fibonacci           |     2 |    21 | cpu_util | %     |    0.0 |   0.0 |   0.0 |      0.0 |     0.0 |    0.0 |
| >>> |_fibonacci(25)                                               |     1 |     1 | cpu_util | %     |   99.9 |  99.9 |  99.9 |     99.9 |     0.0 |    0.0 |
| >>>   |_fibonacci                                                 |     1 |     2 | cpu_util | %     |   99.9 |  99.9 |  99.9 |     99.9 |     0.0 |    0.0 |
|-------------------------------------------------------------------|-------|-------|----------|-------|--------|-------|-------|----------|---------|--------|
| >>>     |_fibonacci                                               |     2 |     3 | cpu_util | %     |   99.9 |  49.9 |  99.0 |    100.4 |     1.0 |    0.0 |
| >>>       |_fibonacci                                             |     4 |     4 | cpu_util | %     |   99.9 |  25.0 |  98.5 |    102.9 |     2.0 |    0.0 |
| >>>         |_fibonacci                                           |     8 |     5 | cpu_util | %     |   99.9 |  12.5 |  93.7 |    104.2 |     3.5 |    0.0 |
| >>>           |_fibonacci                                         |    16 |     6 | cpu_util | %     |   99.9 |   6.2 |  87.8 |    109.8 |     7.2 |    0.0 |
| >>>             |_fibonacci                                       |    32 |     7 | cpu_util | %     |   99.9 |   3.1 |  57.4 |    115.0 |    14.2 |    0.0 |
| >>>               |_fibonacci                                     |    64 |     8 | cpu_util | %     |   99.9 |   1.6 |   0.0 |    186.1 |    39.6 |    0.0 |
| >>>                 |_fibonacci                                   |   128 |     9 | cpu_util | %     |  100.0 |   0.8 |   0.0 |    395.6 |    87.3 |    0.0 |
| >>>                   |_fibonacci                                 |   256 |    10 | cpu_util | %     |  100.1 |   0.4 |   0.0 |   1041.2 |   152.0 |    0.0 |
| >>>                     |_fibonacci                               |   512 |    11 | cpu_util | %     |  100.2 |   0.2 |   0.0 |   2767.5 |   255.6 |    0.0 |
| >>>                       |_fibonacci                             |  1024 |    12 | cpu_util | %     |  100.6 |   0.1 |   0.0 |   7529.6 |   417.8 |    0.0 |
|-------------------------------------------------------------------|-------|-------|----------|-------|--------|-------|-------|----------|---------|--------|
| >>>                         |_fibonacci                           |  2048 |    13 | cpu_util | %     |  100.6 |   0.0 |   0.0 |  12800.8 |   578.2 |    0.0 |
| >>>                           |_fibonacci                         |  4096 |    14 | cpu_util | %     |  100.6 |   0.0 |   0.0 |  22289.1 |   834.7 |    0.0 |
| >>>                             |_fibonacci                       |  8190 |    15 | cpu_util | %     |  101.3 |   0.0 |   0.0 |  81089.8 |  1484.5 |    2.0 |
| >>>                               |_fibonacci                     | 16200 |    16 | cpu_util | %     |   99.3 |   0.0 |   0.0 |  81592.7 |  1578.9 |    0.0 |
| >>>                                 |_fibonacci                   | 29826 |    17 | cpu_util | %     |  101.1 |   0.0 |   0.0 | 698324.0 |  4439.3 |    3.7 |
| >>>                                   |_fibonacci                 | 45638 |    18 | cpu_util | %     |   97.4 |   0.0 |   0.0 |  81149.1 |  1826.8 |    0.0 |
| >>>                                     |_fibonacci               | 52666 |    19 | cpu_util | %     |  103.6 |   0.0 |   0.0 | 728863.0 |  6227.9 |    0.0 |
| >>>                                       |_fibonacci             | 43556 |    20 | cpu_util | %     |  110.5 |   0.0 |   0.0 | 724113.0 |  7742.9 |   12.9 |
| >>>                                         |_fibonacci           | 25232 |    21 | cpu_util | %     |   96.2 |   0.0 |   0.0 | 728863.0 | 11106.9 |   69.5 |
| >>>                                           |_fibonacci         | 10072 |    22 | cpu_util | %     |   29.4 |   0.0 |   0.0 |  80945.4 |   806.6 |  100.0 |
|-------------------------------------------------------------------|-------|-------|----------|-------|--------|-------|-------|----------|---------|--------|
| >>>                                             |_fibonacci       |  2702 |    23 | cpu_util | %     |    0.0 |   0.0 |   0.0 |      0.0 |     0.0 |    0.0 |
| >>>                                               |_fibonacci     |   464 |    24 | cpu_util | %     |    0.0 |   0.0 |   0.0 |      0.0 |     0.0 |    0.0 |
| >>>                                                 |_fibonacci   |    46 |    25 | cpu_util | %     |    0.0 |   0.0 |   0.0 |      0.0 |     0.0 |    0.0 |
| >>>                                                   |_fibonacci |     2 |    26 | cpu_util | %     |    0.0 |   0.0 |   0.0 |      0.0 |     0.0 |    0.0 |
| >>> some_func                                                     |     1 |     0 | cpu_util | %     |    0.0 |   0.0 |   0.0 |      0.0 |     0.0 |    0.0 |
| >>> another_func                                                  |     1 |     0 | cpu_util | %     |    0.0 |   0.0 |   0.0 |      0.0 |     0.0 |    0.0 |
|-------------------------------------------------------------------------------------------------------------------------------------------------------------|

[cpu]|0> Outputting 'timemory-ex-cxx-basic-output/cpu.flamegraph.json'...
[cpu]|0> Outputting 'timemory-ex-cxx-basic-output/cpu.json'...
[cpu]|0> Outputting 'timemory-ex-cxx-basic-output/cpu.txt'...
Opening 'timemory-ex-cxx-basic-output/cpu.jpeg' for output...
Closed 'timemory-ex-cxx-basic-output/cpu.jpeg'...

|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
|                                                                         TOTAL CPU TIME SPENT IN BOTH USER- AND KERNEL-MODE                                                                        |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
|                             LABEL                               |   COUNT    |   DEPTH    |   METRIC   |   UNITS    |    SUM     |    MEAN    |    MIN     |    MAX     |   STDDEV   |   % SELF   |
|-----------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>> fibonacci(15)                                               |          1 |          0 | cpu        | sec        |   0.010000 |   0.010000 |   0.010000 |   0.010000 |   0.000000 |        0.0 |
| >>> |_fibonacci                                                 |          1 |          1 | cpu        | sec        |   0.010000 |   0.010000 |   0.010000 |   0.010000 |   0.000000 |        0.0 |
| >>>   |_fibonacci                                               |          2 |          2 | cpu        | sec        |   0.010000 |   0.005000 |   0.000000 |   0.010000 |   0.007071 |        0.0 |
| >>>     |_fibonacci                                             |          4 |          3 | cpu        | sec        |   0.010000 |   0.002500 |   0.000000 |   0.010000 |   0.005000 |        0.0 |
| >>>       |_fibonacci                                           |          8 |          4 | cpu        | sec        |   0.010000 |   0.001250 |   0.000000 |   0.010000 |   0.003536 |        0.0 |
| >>>         |_fibonacci                                         |         16 |          5 | cpu        | sec        |   0.010000 |   0.000625 |   0.000000 |   0.010000 |   0.002500 |        0.0 |
| >>>           |_fibonacci                                       |         32 |          6 | cpu        | sec        |   0.010000 |   0.000313 |   0.000000 |   0.010000 |   0.001768 |        0.0 |
| >>>             |_fibonacci                                     |         64 |          7 | cpu        | sec        |   0.010000 |   0.000156 |   0.000000 |   0.010000 |   0.001250 |        0.0 |
| >>>               |_fibonacci                                   |        128 |          8 | cpu        | sec        |   0.010000 |   0.000078 |   0.000000 |   0.010000 |   0.000884 |        0.0 |
| >>>                 |_fibonacci                                 |        254 |          9 | cpu        | sec        |   0.010000 |   0.000039 |   0.000000 |   0.010000 |   0.000627 |      100.0 |
|-----------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>                   |_fibonacci                               |        438 |         10 | cpu        | sec        |   0.000000 |   0.000000 |   0.000000 |   0.000000 |   0.000000 |        0.0 |
| >>>                     |_fibonacci                             |        512 |         11 | cpu        | sec        |   0.000000 |   0.000000 |   0.000000 |   0.000000 |   0.000000 |        0.0 |
| >>>                       |_fibonacci                           |        352 |         12 | cpu        | sec        |   0.000000 |   0.000000 |   0.000000 |   0.000000 |   0.000000 |        0.0 |
| >>>                         |_fibonacci                         |        134 |         13 | cpu        | sec        |   0.000000 |   0.000000 |   0.000000 |   0.000000 |   0.000000 |        0.0 |
| >>>                           |_fibonacci                       |         26 |         14 | cpu        | sec        |   0.000000 |   0.000000 |   0.000000 |   0.000000 |   0.000000 |        0.0 |
| >>>                             |_fibonacci                     |          2 |         15 | cpu        | sec        |   0.000000 |   0.000000 |   0.000000 |   0.000000 |   0.000000 |        0.0 |
| >>> fibonacci(20)                                               |          1 |          0 | cpu        | sec        |   0.150000 |   0.150000 |   0.150000 |   0.150000 |   0.000000 |        0.0 |
| >>> |_fibonacci                                                 |          1 |          1 | cpu        | sec        |   0.150000 |   0.150000 |   0.150000 |   0.150000 |   0.000000 |        0.0 |
| >>>   |_fibonacci                                               |          2 |          2 | cpu        | sec        |   0.150000 |   0.075000 |   0.050000 |   0.100000 |   0.035355 |        0.0 |
| >>>     |_fibonacci                                             |          4 |          3 | cpu        | sec        |   0.150000 |   0.037500 |   0.020000 |   0.070000 |   0.022174 |        0.0 |
|-----------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>       |_fibonacci                                           |          8 |          4 | cpu        | sec        |   0.150000 |   0.018750 |   0.010000 |   0.040000 |   0.011260 |        0.0 |
| >>>         |_fibonacci                                         |         16 |          5 | cpu        | sec        |   0.150000 |   0.009375 |   0.000000 |   0.030000 |   0.007719 |        0.0 |
| >>>           |_fibonacci                                       |         32 |          6 | cpu        | sec        |   0.150000 |   0.004687 |   0.000000 |   0.020000 |   0.005671 |        0.0 |
| >>>             |_fibonacci                                     |         64 |          7 | cpu        | sec        |   0.150000 |   0.002344 |   0.000000 |   0.010000 |   0.004270 |        0.0 |
| >>>               |_fibonacci                                   |        128 |          8 | cpu        | sec        |   0.150000 |   0.001172 |   0.000000 |   0.010000 |   0.003229 |        0.0 |
| >>>                 |_fibonacci                                 |        256 |          9 | cpu        | sec        |   0.150000 |   0.000586 |   0.000000 |   0.010000 |   0.002353 |        0.0 |
| >>>                   |_fibonacci                               |        512 |         10 | cpu        | sec        |   0.150000 |   0.000293 |   0.000000 |   0.010000 |   0.001688 |       20.0 |
| >>>                     |_fibonacci                             |       1024 |         11 | cpu        | sec        |   0.120000 |   0.000117 |   0.000000 |   0.010000 |   0.001077 |        8.3 |
| >>>                       |_fibonacci                           |       2026 |         12 | cpu        | sec        |   0.110000 |   0.000054 |   0.000000 |   0.010000 |   0.000735 |       45.5 |
| >>>                         |_fibonacci                         |       3632 |         13 | cpu        | sec        |   0.060000 |   0.000017 |   0.000000 |   0.010000 |   0.000406 |       33.3 |
|-----------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>                           |_fibonacci                       |       5020 |         14 | cpu        | sec        |   0.040000 |   0.000008 |   0.000000 |   0.010000 |   0.000282 |       50.0 |
| >>>                             |_fibonacci                     |       4760 |         15 | cpu        | sec        |   0.020000 |   0.000004 |   0.000000 |   0.010000 |   0.000205 |        0.0 |
| >>>                               |_fibonacci                   |       2942 |         16 | cpu        | sec        |   0.020000 |   0.000007 |   0.000000 |   0.010000 |   0.000261 |       50.0 |
| >>>                                 |_fibonacci                 |       1152 |         17 | cpu        | sec        |   0.010000 |   0.000009 |   0.000000 |   0.010000 |   0.000295 |        0.0 |
| >>>                                   |_fibonacci               |        274 |         18 | cpu        | sec        |   0.010000 |   0.000036 |   0.000000 |   0.010000 |   0.000604 |      100.0 |
| >>>                                     |_fibonacci             |         36 |         19 | cpu        | sec        |   0.000000 |   0.000000 |   0.000000 |   0.000000 |   0.000000 |        0.0 |
| >>>                                       |_fibonacci           |          2 |         20 | cpu        | sec        |   0.000000 |   0.000000 |   0.000000 |   0.000000 |   0.000000 |        0.0 |
| >>> fibonacci(25)                                               |          1 |          0 | cpu        | sec        |   1.330000 |   1.330000 |   1.330000 |   1.330000 |   0.000000 |        0.0 |
| >>> |_fibonacci                                                 |          1 |          1 | cpu        | sec        |   1.330000 |   1.330000 |   1.330000 |   1.330000 |   0.000000 |        0.0 |
| >>>   |_fibonacci                                               |          2 |          2 | cpu        | sec        |   1.330000 |   0.665000 |   0.500000 |   0.830000 |   0.233345 |        0.0 |
|-----------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>     |_fibonacci                                             |          4 |          3 | cpu        | sec        |   1.330000 |   0.332500 |   0.190000 |   0.510000 |   0.132256 |        0.0 |
| >>>       |_fibonacci                                           |          8 |          4 | cpu        | sec        |   1.330000 |   0.166250 |   0.070000 |   0.330000 |   0.079631 |        0.0 |
| >>>         |_fibonacci                                         |         16 |          5 | cpu        | sec        |   1.330000 |   0.083125 |   0.030000 |   0.210000 |   0.045272 |        0.0 |
| >>>           |_fibonacci                                       |         32 |          6 | cpu        | sec        |   1.330000 |   0.041563 |   0.010000 |   0.130000 |   0.025030 |        0.0 |
| >>>             |_fibonacci                                     |         64 |          7 | cpu        | sec        |   1.330000 |   0.020781 |   0.000000 |   0.080000 |   0.014288 |        0.0 |
| >>>               |_fibonacci                                   |        128 |          8 | cpu        | sec        |   1.330000 |   0.010391 |   0.000000 |   0.050000 |   0.008909 |        0.0 |
| >>>                 |_fibonacci                                 |        256 |          9 | cpu        | sec        |   1.330000 |   0.005195 |   0.000000 |   0.030000 |   0.006322 |        0.0 |
| >>>                   |_fibonacci                               |        512 |         10 | cpu        | sec        |   1.330000 |   0.002598 |   0.000000 |   0.020000 |   0.004564 |        0.0 |
| >>>                     |_fibonacci                             |       1024 |         11 | cpu        | sec        |   1.330000 |   0.001299 |   0.000000 |   0.020000 |   0.003392 |        0.8 |
| >>>                       |_fibonacci                           |       2048 |         12 | cpu        | sec        |   1.320000 |   0.000645 |   0.000000 |   0.010000 |   0.002456 |        1.5 |
|-----------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>                         |_fibonacci                         |       4096 |         13 | cpu        | sec        |   1.300000 |   0.000317 |   0.000000 |   0.010000 |   0.001753 |        2.3 |
| >>>                           |_fibonacci                       |       8190 |         14 | cpu        | sec        |   1.270000 |   0.000155 |   0.000000 |   0.010000 |   0.001236 |        7.9 |
| >>>                             |_fibonacci                     |      16200 |         15 | cpu        | sec        |   1.170000 |   0.000072 |   0.000000 |   0.010000 |   0.000847 |       10.3 |
| >>>                               |_fibonacci                   |      29826 |         16 | cpu        | sec        |   1.050000 |   0.000035 |   0.000000 |   0.010000 |   0.000592 |       24.8 |
| >>>                                 |_fibonacci                 |      45638 |         17 | cpu        | sec        |   0.790000 |   0.000017 |   0.000000 |   0.010000 |   0.000416 |       30.4 |
| >>>                                   |_fibonacci               |      52666 |         18 | cpu        | sec        |   0.550000 |   0.000010 |   0.000000 |   0.010000 |   0.000323 |       43.6 |
| >>>                                     |_fibonacci             |      43556 |         19 | cpu        | sec        |   0.310000 |   0.000007 |   0.000000 |   0.010000 |   0.000267 |       64.5 |
| >>>                                       |_fibonacci           |      25232 |         20 | cpu        | sec        |   0.110000 |   0.000004 |   0.000000 |   0.010000 |   0.000209 |       90.9 |
| >>>                                         |_fibonacci         |      10072 |         21 | cpu        | sec        |   0.010000 |   0.000001 |   0.000000 |   0.010000 |   0.000100 |      100.0 |
| >>>                                           |_fibonacci       |       2702 |         22 | cpu        | sec        |   0.000000 |   0.000000 |   0.000000 |   0.000000 |   0.000000 |        0.0 |
|-----------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>                                             |_fibonacci     |        464 |         23 | cpu        | sec        |   0.000000 |   0.000000 |   0.000000 |   0.000000 |   0.000000 |        0.0 |
| >>>                                               |_fibonacci   |         46 |         24 | cpu        | sec        |   0.000000 |   0.000000 |   0.000000 |   0.000000 |   0.000000 |        0.0 |
| >>>                                                 |_fibonacci |          2 |         25 | cpu        | sec        |   0.000000 |   0.000000 |   0.000000 |   0.000000 |   0.000000 |        0.0 |
| >>> some_func                                                   |          1 |          0 | cpu        | sec        |   0.000000 |   0.000000 |   0.000000 |   0.000000 |   0.000000 |        0.0 |
| >>> another_func                                                |          1 |          0 | cpu        | sec        |   0.000000 |   0.000000 |   0.000000 |   0.000000 |   0.000000 |        0.0 |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|

[user]|0> Outputting 'timemory-ex-cxx-basic-output/user.flamegraph.json'...
[user]|0> Outputting 'timemory-ex-cxx-basic-output/user.json'...
[user]|0> Outputting 'timemory-ex-cxx-basic-output/user.txt'...
Opening 'timemory-ex-cxx-basic-output/user.jpeg' for output...
Closed 'timemory-ex-cxx-basic-output/user.jpeg'...

|----------------------------------------------------------------------------------------------------------------------------------------------------|
|                                                             CPU TIME SPENT IN USER-MODE                                                            |
|----------------------------------------------------------------------------------------------------------------------------------------------------|
|      LABEL       |   COUNT    |   DEPTH    |   METRIC   |   UNITS    |    SUM     |    MEAN    |    MIN     |    MAX     |   STDDEV   |   % SELF   |
|------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>> ex_cxx_basic |          1 |          0 | user       | sec        |   1.250000 |   1.250000 |   1.250000 |   1.250000 |   0.000000 |      100.0 |
|----------------------------------------------------------------------------------------------------------------------------------------------------|

[sys]|0> Outputting 'timemory-ex-cxx-basic-output/sys.flamegraph.json'...
[sys]|0> Outputting 'timemory-ex-cxx-basic-output/sys.json'...
[sys]|0> Outputting 'timemory-ex-cxx-basic-output/sys.txt'...
Opening 'timemory-ex-cxx-basic-output/sys.jpeg' for output...
Closed 'timemory-ex-cxx-basic-output/sys.jpeg'...

|----------------------------------------------------------------------------------------------------------------------------------------------------|
|                                                            CPU TIME SPENT IN KERNEL-MODE                                                           |
|----------------------------------------------------------------------------------------------------------------------------------------------------|
|      LABEL       |   COUNT    |   DEPTH    |   METRIC   |   UNITS    |    SUM     |    MEAN    |    MIN     |    MAX     |   STDDEV   |   % SELF   |
|------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>> ex_cxx_basic |          1 |          0 | sys        | sec        |   0.240000 |   0.240000 |   0.240000 |   0.240000 |   0.000000 |      100.0 |
|----------------------------------------------------------------------------------------------------------------------------------------------------|

[wall]|0> Outputting 'timemory-ex-cxx-basic-output/wall.flamegraph.json'...
[wall]|0> Outputting 'timemory-ex-cxx-basic-output/wall.json'...
[wall]|0> Outputting 'timemory-ex-cxx-basic-output/wall.txt'...
Opening 'timemory-ex-cxx-basic-output/wall.jpeg' for output...
Closed 'timemory-ex-cxx-basic-output/wall.jpeg'...

|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
|                                                                               REAL-CLOCK TIMER (I.E. WALL-CLOCK TIMER)                                                                              |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
|                              LABEL                                |   COUNT    |   DEPTH    |   METRIC   |   UNITS    |    SUM     |    MEAN    |    MIN     |    MAX     |   STDDEV   |   % SELF   |
|-------------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>> ex_cxx_basic                                                  |          1 |          0 | wall       | sec        |   1.530347 |   1.530347 |   1.530347 |   1.530347 |   0.000000 |        2.6 |
| >>> |_fibonacci(15)                                               |          1 |          1 | wall       | sec        |   0.015411 |   0.015411 |   0.015411 |   0.015411 |   0.000000 |        0.5 |
| >>>   |_fibonacci                                                 |          1 |          2 | wall       | sec        |   0.015334 |   0.015334 |   0.015334 |   0.015334 |   0.000000 |        0.1 |
| >>>     |_fibonacci                                               |          2 |          3 | wall       | sec        |   0.015311 |   0.007656 |   0.005295 |   0.010016 |   0.003338 |        0.2 |
| >>>       |_fibonacci                                             |          4 |          4 | wall       | sec        |   0.015278 |   0.003819 |   0.002010 |   0.006743 |   0.002037 |        0.3 |
| >>>         |_fibonacci                                           |          8 |          5 | wall       | sec        |   0.015225 |   0.001903 |   0.000757 |   0.004723 |   0.001233 |        0.7 |
| >>>           |_fibonacci                                         |         16 |          6 | wall       | sec        |   0.015116 |   0.000945 |   0.000287 |   0.003435 |   0.000737 |        1.4 |
| >>>             |_fibonacci                                       |         32 |          7 | wall       | sec        |   0.014912 |   0.000466 |   0.000098 |   0.002155 |   0.000392 |        2.6 |
| >>>               |_fibonacci                                     |         64 |          8 | wall       | sec        |   0.014522 |   0.000227 |   0.000029 |   0.001374 |   0.000209 |        5.4 |
| >>>                 |_fibonacci                                   |        128 |          9 | wall       | sec        |   0.013742 |   0.000107 |   0.000002 |   0.000886 |   0.000111 |       11.6 |
|-------------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>                   |_fibonacci                                 |        254 |         10 | wall       | sec        |   0.012149 |   0.000048 |   0.000002 |   0.000580 |   0.000059 |       23.4 |
| >>>                     |_fibonacci                               |        438 |         11 | wall       | sec        |   0.009310 |   0.000021 |   0.000002 |   0.000389 |   0.000032 |       40.2 |
| >>>                       |_fibonacci                             |        512 |         12 | wall       | sec        |   0.005569 |   0.000011 |   0.000002 |   0.000264 |   0.000019 |       56.5 |
| >>>                         |_fibonacci                           |        352 |         13 | wall       | sec        |   0.002422 |   0.000007 |   0.000002 |   0.000182 |   0.000014 |       71.0 |
| >>>                           |_fibonacci                         |        134 |         14 | wall       | sec        |   0.000702 |   0.000005 |   0.000002 |   0.000128 |   0.000012 |       76.4 |
| >>>                             |_fibonacci                       |         26 |         15 | wall       | sec        |   0.000166 |   0.000006 |   0.000002 |   0.000095 |   0.000018 |       92.0 |
| >>>                               |_fibonacci                     |          2 |         16 | wall       | sec        |   0.000013 |   0.000007 |   0.000005 |   0.000008 |   0.000002 |      100.0 |
| >>> |_fibonacci(20)                                               |          1 |          1 | wall       | sec        |   0.144012 |   0.144012 |   0.144012 |   0.144012 |   0.000000 |        0.0 |
| >>>   |_fibonacci                                                 |          1 |          2 | wall       | sec        |   0.143994 |   0.143994 |   0.143994 |   0.143994 |   0.000000 |        0.0 |
| >>>     |_fibonacci                                               |          2 |          3 | wall       | sec        |   0.143979 |   0.071990 |   0.053935 |   0.090044 |   0.025533 |        0.0 |
|-------------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>       |_fibonacci                                             |          4 |          4 | wall       | sec        |   0.143955 |   0.035989 |   0.020645 |   0.056373 |   0.014874 |        0.0 |
| >>>         |_fibonacci                                           |          8 |          5 | wall       | sec        |   0.143908 |   0.017989 |   0.007886 |   0.035197 |   0.008492 |        0.1 |
| >>>           |_fibonacci                                         |         16 |          6 | wall       | sec        |   0.143815 |   0.008988 |   0.003008 |   0.021944 |   0.004776 |        0.1 |
| >>>             |_fibonacci                                       |         32 |          7 | wall       | sec        |   0.143632 |   0.004489 |   0.001144 |   0.013652 |   0.002649 |        0.2 |
| >>>               |_fibonacci                                     |         64 |          8 | wall       | sec        |   0.143273 |   0.002239 |   0.000431 |   0.008528 |   0.001456 |        0.5 |
| >>>                 |_fibonacci                                   |        128 |          9 | wall       | sec        |   0.142532 |   0.001114 |   0.000156 |   0.005286 |   0.000792 |        1.0 |
| >>>                   |_fibonacci                                 |        256 |         10 | wall       | sec        |   0.141099 |   0.000551 |   0.000053 |   0.003268 |   0.000427 |        2.0 |
| >>>                     |_fibonacci                               |        512 |         11 | wall       | sec        |   0.138209 |   0.000270 |   0.000015 |   0.002026 |   0.000229 |        4.1 |
| >>>                       |_fibonacci                             |       1024 |         12 | wall       | sec        |   0.132475 |   0.000129 |   0.000002 |   0.001261 |   0.000122 |        8.5 |
| >>>                         |_fibonacci                           |       2026 |         13 | wall       | sec        |   0.121164 |   0.000060 |   0.000002 |   0.000787 |   0.000065 |       17.5 |
|-------------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>                           |_fibonacci                         |       3632 |         14 | wall       | sec        |   0.099939 |   0.000028 |   0.000002 |   0.000491 |   0.000035 |       30.3 |
| >>>                             |_fibonacci                       |       5020 |         15 | wall       | sec        |   0.069706 |   0.000014 |   0.000002 |   0.000310 |   0.000020 |       45.5 |
| >>>                               |_fibonacci                     |       4760 |         16 | wall       | sec        |   0.037964 |   0.000008 |   0.000002 |   0.000196 |   0.000012 |       59.8 |
| >>>                                 |_fibonacci                   |       2942 |         17 | wall       | sec        |   0.015280 |   0.000005 |   0.000002 |   0.000121 |   0.000008 |       72.0 |
| >>>                                   |_fibonacci                 |       1152 |         18 | wall       | sec        |   0.004276 |   0.000004 |   0.000002 |   0.000074 |   0.000006 |       81.7 |
| >>>                                     |_fibonacci               |        274 |         19 | wall       | sec        |   0.000782 |   0.000003 |   0.000002 |   0.000044 |   0.000004 |       88.2 |
| >>>                                       |_fibonacci             |         36 |         20 | wall       | sec        |   0.000092 |   0.000003 |   0.000002 |   0.000026 |   0.000004 |       94.8 |
| >>>                                         |_fibonacci           |          2 |         21 | wall       | sec        |   0.000005 |   0.000002 |   0.000002 |   0.000002 |   0.000000 |      100.0 |
| >>> |_fibonacci(25)                                               |          1 |          1 | wall       | sec        |   1.331725 |   1.331725 |   1.331725 |   1.331725 |   0.000000 |        0.0 |
| >>>   |_fibonacci                                                 |          1 |          2 | wall       | sec        |   1.331713 |   1.331713 |   1.331713 |   1.331713 |   0.000000 |        0.0 |
|-------------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>     |_fibonacci                                               |          2 |          3 | wall       | sec        |   1.331701 |   0.665851 |   0.505117 |   0.826585 |   0.227312 |        0.0 |
| >>>       |_fibonacci                                             |          4 |          4 | wall       | sec        |   1.331679 |   0.332920 |   0.192966 |   0.515468 |   0.133938 |        0.0 |
| >>>         |_fibonacci                                           |          8 |          5 | wall       | sec        |   1.331639 |   0.166455 |   0.073707 |   0.323379 |   0.077405 |        0.0 |
| >>>           |_fibonacci                                         |         16 |          6 | wall       | sec        |   1.331562 |   0.083223 |   0.028138 |   0.204858 |   0.044040 |        0.0 |
| >>>             |_fibonacci                                       |         32 |          7 | wall       | sec        |   1.331407 |   0.041606 |   0.010735 |   0.131248 |   0.024703 |        0.0 |
| >>>               |_fibonacci                                     |         64 |          8 | wall       | sec        |   1.331106 |   0.020799 |   0.004094 |   0.085401 |   0.013700 |        0.0 |
| >>>                 |_fibonacci                                   |        128 |          9 | wall       | sec        |   1.330503 |   0.010395 |   0.001564 |   0.053644 |   0.007449 |        0.1 |
| >>>                   |_fibonacci                                 |        256 |         10 | wall       | sec        |   1.329291 |   0.005193 |   0.000596 |   0.033155 |   0.004017 |        0.2 |
| >>>                     |_fibonacci                               |        512 |         11 | wall       | sec        |   1.326888 |   0.002592 |   0.000226 |   0.020488 |   0.002151 |        0.4 |
| >>>                       |_fibonacci                             |       1024 |         12 | wall       | sec        |   1.322133 |   0.001291 |   0.000079 |   0.012665 |   0.001146 |        0.7 |
|-------------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>                         |_fibonacci                           |       2048 |         13 | wall       | sec        |   1.312648 |   0.000641 |   0.000024 |   0.007839 |   0.000608 |        1.5 |
| >>>                           |_fibonacci                         |       4096 |         14 | wall       | sec        |   1.292577 |   0.000316 |   0.000002 |   0.004863 |   0.000322 |        3.0 |
| >>>                             |_fibonacci                       |       8190 |         15 | wall       | sec        |   1.254294 |   0.000153 |   0.000001 |   0.003013 |   0.000170 |        6.0 |
| >>>                               |_fibonacci                     |      16200 |         16 | wall       | sec        |   1.178549 |   0.000073 |   0.000001 |   0.001870 |   0.000089 |       11.9 |
| >>>                                 |_fibonacci                   |      29826 |         17 | wall       | sec        |   1.038290 |   0.000035 |   0.000001 |   0.001163 |   0.000048 |       21.8 |
| >>>                                   |_fibonacci                 |      45638 |         18 | wall       | sec        |   0.811494 |   0.000018 |   0.000001 |   0.000726 |   0.000027 |       34.6 |
| >>>                                     |_fibonacci               |      52666 |         19 | wall       | sec        |   0.531105 |   0.000010 |   0.000001 |   0.000454 |   0.000016 |       47.2 |
| >>>                                       |_fibonacci             |      43556 |         20 | wall       | sec        |   0.280563 |   0.000006 |   0.000001 |   0.000287 |   0.000010 |       59.3 |
| >>>                                         |_fibonacci           |      25232 |         21 | wall       | sec        |   0.114308 |   0.000005 |   0.000001 |   0.000182 |   0.000007 |       70.2 |
| >>>                                           |_fibonacci         |      10072 |         22 | wall       | sec        |   0.034050 |   0.000003 |   0.000001 |   0.000110 |   0.000005 |       78.6 |
|-------------------------------------------------------------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|------------|
| >>>                                             |_fibonacci       |       2702 |         23 | wall       | sec        |   0.007279 |   0.000003 |   0.000001 |   0.000067 |   0.000004 |       85.5 |
| >>>                                               |_fibonacci     |        464 |         24 | wall       | sec        |   0.001055 |   0.000002 |   0.000001 |   0.000038 |   0.000003 |       90.8 |
| >>>                                                 |_fibonacci   |         46 |         25 | wall       | sec        |   0.000097 |   0.000002 |   0.000001 |   0.000021 |   0.000003 |       95.9 |
| >>>                                                   |_fibonacci |          2 |         26 | wall       | sec        |   0.000004 |   0.000002 |   0.000002 |   0.000002 |   0.000000 |      100.0 |
| >>> some_func                                                     |          1 |          0 | wall       | sec        |   0.010067 |   0.010067 |   0.010067 |   0.010067 |   0.000000 |      100.0 |
| >>> another_func                                                  |          1 |          0 | wall       | sec        |   0.010065 |   0.010065 |   0.010065 |   0.010065 |   0.000000 |      100.0 |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|


[metadata::manager::finalize]> Outputting 'timemory-ex-cxx-basic-output/metadata.json'...


#---------------------- tim::manager destroyed [rank=0][id=0][pid=1574] ----------------------#
```